@@ -3,7 +3,7 @@
 #' Supplies implementations of higher order "fluid data" transforms.  These'
 #' transforms move data between rows and columns, are controlled by a graphical
 #' transformation specification, and have pivot and un-pivot as special cases.
-#' Implementation is based on 'DBI' and 'RSQLite', so should be usable on
+#' Large scale implementation is based on 'DBI', so should be usable on
 #' 'DBI' compliant data sources (include large systems such as 'PostgreSQL' and
 #' 'Spark').  Convenience adapters are provided for in-memory 'data.frame's.
 #' A theory of fluid data transforms can be found in the following articles:
@@ -18,6 +18,5 @@ NULL
 # make sure dot doesn't look like an unbound ref
 . <- NULL
 
-#' @importFrom wrapr grepdf mk_tmp_name_source := let %.>%
-#' @export
-wrapr::grepdf
+#' @importFrom wrapr mk_tmp_name_source := let %.>%
+NULL
